@@ -9,9 +9,9 @@ import (
 	"os"
 
 	"github.com/oauth2-proxy/oauth2-proxy/v7/pkg/apis/options"
-	. "github.com/onsi/ginkgo"
-	. "github.com/onsi/ginkgo/extensions/table"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	. "github.com/onsi/gomega/gleak"
 )
 
 const hello = "Hello World!"
@@ -559,6 +559,8 @@ var _ = Describe("Server", func() {
 
 		AfterEach(func() {
 			cancel()
+			Eventually(Goroutines).ShouldNot(HaveLeaked())
+
 		})
 
 		Context("with an ipv4 http server", func() {
@@ -584,7 +586,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(listenAddr)
+				resp, err := httpGet(ctx, listenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -599,13 +601,13 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				_, err := client.Get(listenAddr)
+				_, err := httpGet(ctx, listenAddr)
 				Expect(err).ToNot(HaveOccurred())
 
 				cancel()
 
 				Eventually(func() error {
-					_, err := client.Get(listenAddr)
+					_, err := httpGet(ctx, listenAddr)
 					return err
 				}).Should(HaveOccurred())
 			})
@@ -638,7 +640,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(secureListenAddr)
+				resp, err := httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -653,13 +655,13 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				_, err := client.Get(secureListenAddr)
+				_, err := httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 
 				cancel()
 
 				Eventually(func() error {
-					_, err := client.Get(secureListenAddr)
+					_, err := httpGet(ctx, secureListenAddr)
 					return err
 				}).Should(HaveOccurred())
 			})
@@ -670,7 +672,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(secureListenAddr)
+				resp, err := httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -709,7 +711,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(listenAddr)
+				resp, err := httpGet(ctx, listenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -724,7 +726,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(secureListenAddr)
+				resp, err := httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -739,19 +741,19 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				_, err := client.Get(listenAddr)
+				_, err := httpGet(ctx, listenAddr)
 				Expect(err).ToNot(HaveOccurred())
-				_, err = client.Get(secureListenAddr)
+				_, err = httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 
 				cancel()
 
 				Eventually(func() error {
-					_, err := client.Get(listenAddr)
+					_, err := httpGet(ctx, listenAddr)
 					return err
 				}).Should(HaveOccurred())
 				Eventually(func() error {
-					_, err := client.Get(secureListenAddr)
+					_, err := httpGet(ctx, secureListenAddr)
 					return err
 				}).Should(HaveOccurred())
 			})
@@ -781,7 +783,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(listenAddr)
+				resp, err := httpGet(ctx, listenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -796,13 +798,13 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				_, err := client.Get(listenAddr)
+				_, err := httpGet(ctx, listenAddr)
 				Expect(err).ToNot(HaveOccurred())
 
 				cancel()
 
 				Eventually(func() error {
-					_, err := client.Get(listenAddr)
+					_, err := httpGet(ctx, listenAddr)
 					return err
 				}).Should(HaveOccurred())
 			})
@@ -836,7 +838,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(secureListenAddr)
+				resp, err := httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -851,13 +853,13 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				_, err := client.Get(secureListenAddr)
+				_, err := httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 
 				cancel()
 
 				Eventually(func() error {
-					_, err := client.Get(secureListenAddr)
+					_, err := httpGet(ctx, secureListenAddr)
 					return err
 				}).Should(HaveOccurred())
 			})
@@ -868,7 +870,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(secureListenAddr)
+				resp, err := httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -908,7 +910,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(listenAddr)
+				resp, err := httpGet(ctx, listenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -923,7 +925,7 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				resp, err := client.Get(secureListenAddr)
+				resp, err := httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(resp.StatusCode).To(Equal(http.StatusOK))
 
@@ -938,19 +940,19 @@ var _ = Describe("Server", func() {
 					Expect(srv.Start(ctx)).To(Succeed())
 				}()
 
-				_, err := client.Get(listenAddr)
+				_, err := httpGet(ctx, listenAddr)
 				Expect(err).ToNot(HaveOccurred())
-				_, err = client.Get(secureListenAddr)
+				_, err = httpGet(ctx, secureListenAddr)
 				Expect(err).ToNot(HaveOccurred())
 
 				cancel()
 
 				Eventually(func() error {
-					_, err := client.Get(listenAddr)
+					_, err := httpGet(ctx, listenAddr)
 					return err
 				}).Should(HaveOccurred())
 				Eventually(func() error {
-					_, err := client.Get(secureListenAddr)
+					_, err := httpGet(ctx, secureListenAddr)
 					return err
 				}).Should(HaveOccurred())
 			})
